@@ -11,19 +11,23 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
-'''Command line interface for *didjvu*'''
+'''command line interface for *didjvu*'''
 
-import argparse
+from . import utils
 
 try:
-    import gamera
-except ImportError:
-    gamera = None
+    import argparse
+except ImportError, ex:
+    utils.enhance_import_error(ex, 'argparse', 'python-argparse', 'http://code.google.com/p/argparse/')
+    raise
 
 from . import djvu_extra as djvu
-from . import version
-
-__version__ = version.__version__
+from . import version as version_module
+try:
+    from . import xmp
+except ImportError, xmp_import_error:
+    utils.enhance_import_error(xmp_import_error, 'python-xmp-toolkit', 'python-libxmp', 'http://code.google.com/p/python-xmp-toolkit/')
+    xmp = None
 
 def range_int(x, y, typename):
     class rint(int):
@@ -73,11 +77,7 @@ class ArgumentParser(argparse.ArgumentParser):
 
     def __init__(self, methods, default_method):
         argparse.ArgumentParser.__init__(self, formatter_class=argparse.RawDescriptionHelpFormatter)
-        version = '%(prog)s ' + __version__
-        try:
-            version += ' (Gamera %s)' % gamera.__version__
-        except (AttributeError, TypeError, ValueError):
-            pass
+        version = version_module.get_software_agent()
         self.add_argument('--version', action='version', version=version, help='show version information and exit')
         p_separate = self.add_subparser('separate', help='generate masks for images')
         p_encode = self.add_subparser('encode', help='convert images to single-page DjVu documents')
@@ -111,6 +111,8 @@ class ArgumentParser(argparse.ArgumentParser):
             if p is p_bundle:
                 p.add_argument('-p', '--pages-per-dict', type=int, metavar='N', help='how many pages to compress in one pass')
             p.add_argument('-m', '--method', choices=methods, type=replace_underscores, default=default_method, help='binarization method')
+            if p is p_encode:
+                p.add_argument('--xmp', action='store_true', help='create sidecar XMP metadata (experimental!)')
             p.add_argument('-v', '--verbose', dest='verbosity', action='append_const', const=None, help='more informational messages')
             p.add_argument('-q', '--quiet', dest='verbosity', action='store_const', const=[], help='no informational messages')
             p.add_argument('input', metavar='<input-image>', nargs='+')
@@ -159,6 +161,11 @@ class ArgumentParser(argparse.ArgumentParser):
             o.pages_per_dict = 1
         action = getattr(actions, vars(o).pop('_action_'))
         o.method = self.__methods[o.method]
+        try:
+            if not xmp and o.xmp:
+                raise xmp_import_error
+        except AttributeError:
+            pass
         return action(o)
 
 __all__ = ['ArgumentParser']
