@@ -11,7 +11,7 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
-'''Wrappers for the DjVuLibre utilities'''
+'''wrappers for the DjVuLibre utilities'''
 
 from __future__ import with_statement
 
